summaryrefslogtreecommitdiffstats
path: root/kmix/ksmallslider.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:47:46 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:47:46 -0600
commit27430f06c6cc2187c639f59f342f07f1fde91a8b (patch)
tree493c1095950b7f0a82690cedac1b749666be1b47 /kmix/ksmallslider.cpp
parent794a886cbd6d6893d62026f3800b95051652fc5a (diff)
downloadtdemultimedia-27430f06c6cc2187c639f59f342f07f1fde91a8b.tar.gz
tdemultimedia-27430f06c6cc2187c639f59f342f07f1fde91a8b.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'kmix/ksmallslider.cpp')
-rw-r--r--kmix/ksmallslider.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmix/ksmallslider.cpp b/kmix/ksmallslider.cpp
index b1f6569e..08bee03b 100644
--- a/kmix/ksmallslider.cpp
+++ b/kmix/ksmallslider.cpp
@@ -473,9 +473,9 @@ void KSmallSlider::paletteChange ( const TQPalette &) {
setColors(mutedLowColor2, mutedHighColor2, backColor2 );
}
else {
// ignore the TQPalette and use the values from KGlobalSettings instead
//const TQColorGroup& qcg = palette().active();
- setColors(KGlobalSettings::baseColor(), KGlobalSettings::highlightColor(), backColor2 );
+ setColors(TDEGlobalSettings::baseColor(), TDEGlobalSettings::highlightColor(), backColor2 );
}
}
*/
@@ -473,9 +473,9 @@ void KSmallSlider::paletteChange ( const TQPalette &) {
}
else {
- // ignore the TQPalette and use the values from KGlobalSettings instead
+ // ignore the TQPalette and use the values from TDEGlobalSettings instead
//const TQColorGroup& qcg = palette().active();